Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Threading.Tasks
Imports System.Windows.Forms
Imports System.IO
Imports ColorCode
Imports SelectPdf

Namespace SelectPdf.Samples
    Partial Public Class AutomaticBookmarks
        Inherits Form

        Private url As String = Path.GetFullPath(AppDomain.CurrentDomain.BaseDirectory + _
                                                 "/../../files/document.html")

        Private Sub BtnCreatePdf_Click(sender As Object, e As EventArgs) _
            Handles BtnCreatePdf.Click
            Cursor = Cursors.WaitCursor
            Dim file As String = "Document.pdf"

            Try
                ' instantiate a html to pdf converter object
                Dim converter As New HtmlToPdf()

                ' set the css selectors for the automatic bookmarks
                converter.Options.PdfBookmarkOptions.CssSelectors = _
                    TxtElements.Text.Split(New Char() {","c})

                ' display the bookmarks when the document is opened in a viewer
                converter.Options.ViewerPreferences.PageMode = PdfViewerPageMode.UseOutlines

                ' create a new pdf document converting an url
                Dim doc As PdfDocument = converter.ConvertUrl(TxtUrl.Text)

                ' save pdf document
                doc.Save(file)

                ' close pdf document
                doc.Close()
            Catch ex As Exception
                MessageBox.Show([String].Format("Error: {0}", ex.Message), "Error", _
                                MessageBoxButtons.OK, MessageBoxIcon.[Error])
                Return
            Finally
                Cursor = Cursors.Arrow
            End Try

            ' open generated pdf
            Try
                System.Diagnostics.Process.Start(file)
            Catch
                MessageBox.Show("Could not open generated pdf document", "Error", _
                                MessageBoxButtons.OK, MessageBoxIcon.[Error])
            End Try
        End Sub

        Public Sub New()
            InitializeComponent()

            TxtUrl.Text = url

            Try
                ' display highlighted sample code
                Dim code As String = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory + _
                                                      "/../../" + "AutomaticBookmarks.vb")
                WBSampleCode.DocumentText = New CodeColorizer().Colorize(code, Languages.VbDotNet)
            Catch
                WBSampleCode.DocumentText = "Sample code not available"
            End Try
        End Sub

        Private Sub LblTestFile_Click(sender As Object, e As EventArgs) Handles LblTestFile.Click
            System.Diagnostics.Process.Start(url)
        End Sub
    End Class
End Namespace
